@@ -24,18 +24,16 @@
 #ifndef AWARDS_H
 #define AWARDS_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 // This class shall read the awardsrc file to know which awards we want to
 // check and then will read and create the awards.
-#include <qvaluelist.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qtextstream.h>
-#include <qstring.h>
+//#include <q3valuelist.h>
+#include <QList>
+#include <QFile>
+#include <QDir>
+#include <QTextStream>
+#include <QString>
 //#include <klocale.h>
-#include <qstringlist.h>
+#include <QStringList>
 #include "world.h"
 #include "reference.h"
 #include "award.h"
@@ -45,32 +43,32 @@ class Awards  {
 // The user can create awards' files and KLog will read it and manage
 // the award for the user's log
 public:
-	Awards();
-	~Awards();
-	
-	void readConfig();
-	int checkPrefix(const QString &tprefix);
-		// Returns the Award for a Prefix or -1 if none
-	QString getAwardName (const QString &tprefix);
-	Award getAwardFor(const QString &tprefix);
-	//Award getIntAwardFor(int tEntity);
-	Award getDefaultAward();
-	QStringList getAwardReferences(Award &taward);
-	void clearAwards();
-	void deleteAward(Award &taward);
-		//Returns a QStringlist with all the references of an award
-	
+    Awards();
+    ~Awards();
+
+    void readConfig();
+    int checkPrefix(const QString &tprefix);
+        // Returns the Award for a Prefix or -1 if none
+    QString getAwardName (const QString &tprefix);
+    Award getAwardFor(const QString &tprefix);
+    //Award getIntAwardFor(int tEntity);
+    Award getDefaultAward();
+    QStringList getAwardReferences(Award &taward);
+    void clearAwards();
+    void deleteAward(Award &taward);
+        //Returns a QStringlist with all the references of an award
+
 private:
-	typedef QValueList<Award> ListOfAwards; // The list of references of the award.
-	ListOfAwards listOfAwards;		// The references of the current award.
-	QString awardFile;
-	QString klogDir;
-	bool dirExist;
-	Award awardAux;	
-	Award awardDefault;		// The defaultAward;
-	QStringList listOfReferences;
-	int awardReference;
-	
+    typedef QList<Award> ListOfAwards; // The list of references of the award.
+    ListOfAwards listOfAwards;		// The references of the current award.
+    QString awardFile;
+    QString klogDir;
+    bool dirExist;
+    Award awardAux;
+    Award awardDefault;		// The defaultAward;
+    QStringList listOfReferences;
+    int awardReference;
+
 };
 
 #endif
