@@ -39,13 +39,12 @@
 //static const char *description = I18N_NOOP("The KDE Ham Radio Logging Software");
 
 
-int main (int argc, char *argv[])
-{
+int main (int argc, char *argv[]){
   KAboutData aboutData( "klog", "klog",
-      ki18n("KLog"), "0.5.6",
-      ki18n("The KDE Ham radio loggin software."),
-      KAboutData::License_GPL,
-      ki18n("Copyright (c) 2002-2010, Jaime Robles, EA4TV") );
+  ki18n("KLog"), "0.5.7",
+  ki18n("The KDE Ham radio loggin software."),
+  KAboutData::License_GPL,
+  ki18n("Copyright (c) 2002-2010, Jaime Robles, EA4TV") );
 //    aboutData.addAuthor("Jaime Robles, EA4TV","http://jaime.robles.es", "jaime@robles.es");
   //TODO: Add the command line options
   KCmdLineArgs::init( argc, argv, &aboutData );
@@ -56,7 +55,7 @@ int main (int argc, char *argv[])
  
   KApplication app;
  
-  Klog* klog = new Klog();
+  Klog* klog = new Klog("0.5.7");
   klog->show();
  
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs(); //new
